Nanopot
=======

Ivchepot is a simple TCP honeypot written in Python 3.

Source code
-----------
https://github.com/Ivche1337/Ivchepot


Documentation
-------------
https://ivchepot.rtfd.io

Documentation can be found in the `docs/` directory
as reStructuredText files.Build the docs by running `make` 
in the `docs/` directory, then viewing `docs/_build/html/index.html`.


Author
------
Ivche1337 <ivchepro@gmail.com>


Credits
-------
This project was done just for learning purposes
and i am not the original creator  of it.
Original creator: https://www.youtube.com/DevDungeon